TransformTreeContext

Struct TransformTreeContext 

pub struct TransformTreeContext { /* private fields */ }
Provides a transform tree for the view & time it operates on.

Will do the necessary bulk processing of transform information and make it available for quick lookups by visualizers.

Implementations

Source

impl TransformTreeContext

pub fn target_from_entity_path( &self, entity_path_hash: EntityPathHash, ) -> Option<&Result<TransformInfo, TransformFromToError>>

Returns a transform info describing how to get to the view’s target frame for the given entity.

pub fn pinhole_tree_root_info( &self, frame: TransformFrameIdHash, ) -> Option<&PinholeTreeRoot>

Returns the properties of the pinhole tree root at given frame if the entity’s root is a pinhole tree root.

pub fn target_from_pinhole_root( &self, frame: TransformFrameIdHash, ) -> Option<DAffine3>

Returns the transform from a pinhole root to the target frame if any.

This is effectively the extrinsic portion of the pinhole’s transform to the view’s target frame. Note that this may otherwise not be accessible since we allow both extrinsics and intrinsics to be on a transform between two frames, with no transform frame representing just the extrinsics.

Returns None if the path is not a pinhole root, or is not connected to the target frame or the target frame does not exist in the forest (i.e. is invalid).

pub fn transform_forest(&self) -> &TransformForest

The full transform forest

pub fn target_frame(&self) -> TransformFrameIdHash

Returns the target frame, also known as the space origin.

pub fn target_frame_pinhole_root(&self) -> Option<TransformFrameIdHash>

Iff the target frame has a pinhole tree root, returns its transform frame id.

If this is Some, then this is either the frame target frame itself or one of its ancestors. Some implies that the view as a whole is two dimensional.

pub fn transform_frame_id_for( &self, entity_path: EntityPathHash, ) -> TransformFrameIdHash

Returns the transform frame id for a given entity path.

pub fn child_frames_for_entity( &self, entity_path: EntityPathHash, ) -> impl Iterator<Item = (&TransformFrameIdHash, &TreeTransform)>

Returns all reachable frame for the current root.

pub fn lookup_frame_id( &self, frame_id_hash: TransformFrameIdHash, ) -> Option<&TransformFrameId>

Looks up a frame ID by its hash.

Returns None if the frame id hash was never encountered.

pub fn is_empty_frame_name(&self, frame_id_hash: TransformFrameIdHash) -> bool

pub fn format_frame_or_debug_warn( &self, frame_id_hash: TransformFrameIdHash, debug_location: &EntityPath, ) -> Option<String>

Formats a frame ID hash as a human-readable string.

Returns the frame name if known, otherwise logs a warning in debug builds and returns None.